changeset 29673:674d1b0272a7

jabber: Eliminate spurious warning when connecting to Facebook. Fixes #11320 committer: Paul Aurich <paul@darkrain42.org>
author dreiss@facebook.com
date Sat, 03 Apr 2010 06:07:04 +0000
parents 51f997e2347f
children ba2b9a097da9
files ChangeLog libpurple/protocols/jabber/auth_cyrus.c
diffstat 2 files changed, 8 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/ChangeLog	Sat Apr 03 05:09:28 2010 +0000
+++ b/ChangeLog	Sat Apr 03 06:07:04 2010 +0000
@@ -73,6 +73,8 @@
 	* Validate the hash on incoming BoB data objects (for custom smileys etc.),
 	  cache based per JID when the CID is not a valid hash (as specified by the
 	  BoB XEP).
+	* Present a better error message when authentication fails while trying
+	  to connect to Facebook.  (David Reiss, Facebook)
 
 	Yahoo/Yahoo JAPAN:
 	* Attempt to better handle transparent proxies interfering with HTTP-based
--- a/libpurple/protocols/jabber/auth_cyrus.c	Sat Apr 03 05:09:28 2010 +0000
+++ b/libpurple/protocols/jabber/auth_cyrus.c	Sat Apr 03 06:07:04 2010 +0000
@@ -404,11 +404,13 @@
 			continue;
 		}
 
 		/* Don't include Google Talk's X-GOOGLE-TOKEN mechanism, as we will not
 		 * support it and including it gives a false fall-back to other mechs offerred,
 		 * leading to incorrect error handling.
 		 */
-		if (g_str_equal(mech_name, "X-GOOGLE-TOKEN")) {
+		if (g_str_equal(mech_name, "X-GOOGLE-TOKEN")
+				|| g_str_equal(mech_name, "X-FACEBOOK-PLATFORM") ) {
 			g_free(mech_name);
 			continue;
 		}
@@ -404,11 +404,13 @@
 		}
 
-		/* Don't include Google Talk's X-GOOGLE-TOKEN mechanism, as we will not
-		 * support it and including it gives a false fall-back to other mechs offerred,
-		 * leading to incorrect error handling.
+		/* Don't include Google Talk's X-GOOGLE-TOKEN mechanism
+		 * or Facebook Chat's X-FACEBOOK-PLATFORM mechansim,
+		 * as we will not support them and including them gives a false fall-back
+		 * to other mechs offerred, leading to incorrect error handling.
 		 */